﻿<#
.SYNOPSIS
Gets the names and SIDs of the principals (user or group) in an item's ACL.

.DESCRIPTION
Uses the psgetsid utility from Sysinternals to get the SID of a principal.
Adjust psgetsid's location ($PSGETSID) to reflect your environment.

.PARAMETER Path
Path of the item (folder, file, registry key...).

.PARAMETER NotInheritedOnly
Display only principals form ACLs, which are not inherited.

.NOTES
Author: Micskei Zoltan, 2013.03.01.
#>

param(
    [Parameter(Mandatory=$true)][String] $Path,
    [switch] $NotInheritedOnly
)

# Constants
$PSGETSID = "C:\Program Files\sysinternals\psgetsid.exe"

# Check input parameter and constants
if (! (Test-Path $Path))
{
	throw "$Path does not exists, correct -Path parameter!"
}

if (! (Test-Path $PSGETSID))
{
	throw "Adjust the locations of psgetsid.exe in the `$PSGETSID constant!"
}

# Hashtable to collect the principals
$principals = @{}

(Get-Acl $Path).Access | % {
	if ( ! ( $NotInheritedOnly -and ($_.IsInherited) ) )
	{
		# Select-String keeps only the SID from psgetsid's output
		$sid = (& $PSGETSID $_.IdentityReference) 2> $null | Select-String "S-1"
		
		if (! ($principals.ContainsKey($_.IdentityReference) ) )
		{
			$principals.Add($_.IdentityReference, $sid)
		}
	}
}

Write-Output $principals