#!/usr/bin/env python3
'''
This script greets a user on screen and optionally in a file.
Usage: ParameterHandlingArgParse.py [-h] [-q QUANTITY] [-f FILE] [-X] name
Tutorial on argparse: http://docs.python.org/3.3/howto/argparse.html#id1

Created on 2013.02.19.
@author: Gergo Horanyi

'''

import argparse
import sys
import os.path

# Argument parser initialization
parser = argparse.ArgumentParser();
parser.add_argument("name", help="The name to be greeted.", type=str)
parser.add_argument("-q", "--quantity", help="Amount of greetings.", type=int, default=1)
parser.add_argument("-f", "--file", help="If specified, the output is written to new file.", type=str)
parser.add_argument("-X", help="Force to overwrite output file", action="store_true")
args = parser.parse_args();

# Argument checking
if args.quantity < 0:
    print("ERROR: Quantity shall be a positive number.")
    sys.exit(1)

# Print greeting to screen
i = 0
while i < args.quantity:
    print("Hello ", args.name, "!", sep="")
    i = i+1

# File handling
if args.file is not None:
    if os.path.exists(args.file) and args.X == False:
        print("ERROR: Output file already exists. Use -X to overwrite.")
        sys.exit(2)
    else: # Write to file
        f = open(args.file, 'w')
        i = 0
        while i < args.quantity:
            f.write("Hello " + args.name + "!\n")
            i = i+1
        f.close()
        