'''
This script receives a CSV file with directories and associated users and an output folder.
The script creates all the directories in the CSV, and gives permission to the associated users. If the user does not exist, a new user is created.
The script shall be started as root.
The format of the input CSV:
dir1,user1
dir1,user2
dir2,user2


Created on 2013.02.19.
@author: Gergo Horanyi

'''

import argparse
import os.path
import sys
import csv

# Initialize argparser
parser = argparse.ArgumentParser()
parser.add_argument("input", help="The path to the input CSV file containing the directories and users to be created.")
parser.add_argument("output", help="The parent directory where the new directories shall be created.")

# Parameter checking
args = parser.parse_args()
if not os.path.exists(args.input):
    print("ERROR: The given input file does not exist.")
    sys.exit(1)
elif not os.path.isdir(args.output):
    print("ERROR: The give output directory does not exist or not a directory.")
    sys.exit(2)
elif os.popen("id -nu").read() != "root":
    print("ERROR: The script shall be started as root (with sudo).")
    sys.exit(3)
else: # Everything seems to be all right
    inputFile = open(args.input)
    for row in csv.reader(inputFile).readLines(): # Iterate over the rows of the CSV file
        directory = row[0]
        user = row[1]
        if int(os.popen("grep " + user + " /etc/passwd | grep -c ':'").read()) == 0: # Check whether the user exists
            print("New user shall be added:", user)
            os.system("useradd " + user)
        if not args.output.endswith("/"): # Check whether the output parameter has an "/" at the end
            parent = args.output + "/"
        else:
            parent = args.output
        if not os.path.isdir(parent + directory): # Create directory if not exists
            os.makedirs(parent + directory)
        groupname = "irf_example_group_" + directory
        os.system("groupadd " + groupname) # Create group for directory
        os.system("chgrp -R " + groupname + " " + parent + directory) # Set the group of the directory
        os.system("chmod a-rwx " + parent + directory) # Revoke all permissions from the directory
        os.system("chmod a+rwx " + parent + directory) # Add all permissions for the directory
        os.system("usermod -a -G " + groupname + " " + user) # Add the user to the group.
        sys.exit(0)
